import{u as g,V as _,W as y,X as h,Y as v}from"./reka-ui-D1_Wa3oe.js";import{d as p,G as l,u as e,D as c,H as s,h as u,L as B,M as P,e as f,J as w}from"./lucide-UY9XeFdQ.js";import{c as O}from"./index-CKxLfxpS.js";import{l as b}from"./vueuse-Dj-fx4H6.js";const A=p({__name:"Popover",props:{defaultOpen:{type:Boolean},open:{type:Boolean},modal:{type:Boolean}},emits:["update:open"],setup(o,{emit:t}){const n=g(o,t);return(i,d)=>(f(),l(e(_),c({"data-slot":"popover"},e(n)),{default:s(m=>[u(i.$slots,"default",B(P(m)))]),_:3},16))}}),F=p({inheritAttrs:!1,__name:"PopoverContent",props:{forceMount:{type:Boolean},side:{},sideOffset:{default:4},sideFlip:{type:Boolean},align:{default:"center"},alignOffset:{},alignFlip:{type:Boolean},avoidCollisions:{type:Boolean},collisionBoundary:{},collisionPadding:{},arrowPadding:{},hideShiftedArrow:{type:Boolean},sticky:{},hideWhenDetached:{type:Boolean},positionStrategy:{},updatePositionStrategy:{},disableUpdateOnLayoutShift:{type:Boolean},prioritizePosition:{type:Boolean},reference:{},asChild:{type:Boolean},as:{},disableOutsidePointerEvents:{type:Boolean},class:{type:[Boolean,null,String,Object,Array],default:void 0}},emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","openAutoFocus","closeAutoFocus"],setup(o,{emit:t}){const a=o,r=t,n=b(a,"class"),i=g(n,r);return(d,m)=>(f(),l(e(y),null,{default:s(()=>[w(e(h),c({"data-slot":"popover-content"},{...d.$attrs,...e(i)},{class:e(O)("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 !z-[10000] w-72 rounded-md border p-4 shadow-md origin-(--reka-popover-content-transform-origin) outline-hidden",a.class)}),{default:s(()=>[u(d.$slots,"default")]),_:3},16,["class"])]),_:3}))}}),k=p({__name:"PopoverTrigger",props:{asChild:{type:Boolean},as:{}},setup(o){const t=o;return(a,r)=>(f(),l(e(v),c({"data-slot":"popover-trigger"},t),{default:s(()=>[u(a.$slots,"default")]),_:3},16))}});export{A as _,k as a,F as b};
