.selectable[data-v-e45cfff0]{-webkit-user-select:text;-khtml-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text}.background-image[data-v-e45cfff0]{position:absolute}.background-image .v-img__img--cover[data-v-e45cfff0]{object-position:50% 20%}.v-card--variant-elevated[data-v-e45cfff0]{box-shadow:none;border-width:1px;border-style:solid;font-size:smaller}.description-text[data-v-e45cfff0] div{display:-webkit-box;-webkit-line-clamp:5;line-clamp:5;-webkit-box-orient:vertical;overflow:hidden;text-overflow:ellipsis;white-space:normal;word-break:break-word}@media(max-width:1280px){.description-text[data-v-e45cfff0] div{-webkit-line-clamp:3;line-clamp:3}}
