import{I as f}from"./InfoHeader-CoNYNcZm.js";import{I as v}from"./ItemsListing-DdSUpMhP.js";import{_ as I}from"./ProviderDetails.vue_vue_type_style_index_0_lang-CXtwfgiQ.js";import{a,E as _}from"./index-CKxLfxpS.js";import{d as h,w as b,o as w,r as p,a3 as y,b as k,J as E,G as n,K as l,F as D,e as r}from"./lucide-UY9XeFdQ.js";import"./Toolbar-Da01lZeW.js";import"./vuetify-C0IIhwYL.js";import"./marquee_text_sync-C4anEqYx.js";import"./vue-router-DNlH4vva.js";import"./MarqueeText-DvK0-Oq1.js";import"./MediaItemThumb-DiY2t3Gt.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-DYXAnx83.js";import"./vue-i18n-DwYfJ_fn.js";import"./Container-B1UOd5ED.js";import"./index-kQIztB-E.js";import"./userPreferences-BgjK7xB_.js";import"./Button-DdCpYaoc.js";import"./ListItem-BP0lui-9.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-CnaMVQug.js";import"./PanelviewItemCompact-BhrDAsYI.js";import"./color-CcshWhNz.js";import"./qrcode-CJNXjF_3.js";import"./marked-D9eDbhZJ.js";import"./vueuse-Dj-fx4H6.js";/* empty css            */import"./swiper-DNx4mJDO.js";const X=h({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(d){const e=d,i=p(!1),t=p(),u=async function(){t.value=await a.getPodcast(e.itemId,e.provider)};b(()=>e.itemId,o=>{o&&u()},{immediate:!0}),w(()=>{const o=a.subscribe(_.MEDIA_ITEM_UPDATED,s=>{const m=s.data;t.value?.uri==m.uri&&(t.value=m,i.value=!0)});y(o)});const c=async function(o){return await a.getPodcastEpisodes(e.itemId,e.provider)};return(o,s)=>(r(),k(D,null,[E(f,{item:t.value},null,8,["item"]),t.value?(r(),n(v,{key:0,itemtype:"podcastepisodes","parent-item":t.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":c,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${e.itemId}.${e.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):l("",!0),t.value?(r(),n(I,{key:1,"item-details":t.value},null,8,["item-details"])):l("",!0)],64))}});export{X as default};
