import{Z as r}from"./reka-ui-D1_Wa3oe.js";import{c as l}from"./index-CKxLfxpS.js";import{d as n,G as p,u as e,D as c,H as d,h as i,e as m}from"./lucide-UY9XeFdQ.js";import{l as u}from"./vueuse-Dj-fx4H6.js";const h=n({__name:"Label",props:{for:{},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(s){const a=s,t=u(a,"class");return(o,f)=>(m(),p(e(r),c({"data-slot":"label"},e(t),{class:e(l)("flex items-center gap-2 text-sm leading-none font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50",a.class)}),{default:d(()=>[i(o.$slots,"default")]),_:3},16,["class"]))}});export{h as _};
