import{m as l,e as n}from"./reka-ui-D1_Wa3oe.js";import{c}from"./index-CKxLfxpS.js";import{d as p,G as i,H as d,h as m,D as f,u as s,e as u}from"./lucide-UY9XeFdQ.js";import{l as _}from"./vueuse-Dj-fx4H6.js";const P=p({__name:"DialogDescription",props:{asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(o){const e=o,a=_(e,"class"),t=l(a);return(r,g)=>(u(),i(s(n),f({"data-slot":"dialog-description"},s(t),{class:s(c)("text-muted-foreground text-sm",e.class)}),{default:d(()=>[m(r.$slots,"default")]),_:3},16,["class"]))}});export{P as _};
