import{M as f}from"./index-kQIztB-E.js";import{c as i,d as m,Z as d,G as p,ar as h,O as C,D as _,u,e as v,H as P,h as b}from"./lucide-UY9XeFdQ.js";import{u as w,h as y}from"./vuetify-C0IIhwYL.js";import{_ as g}from"./index-CKxLfxpS.js";const k=(a,s)=>{const r=i(()=>{const{variant:n,...e}=a;return{...e,fluid:a.fluid!==!1}}),o=i(()=>{const n=f(a.variant).with("panel",()=>["container-main","container-panel",s?"container-panel--dark":"container-panel--light"]).with("compact",()=>["container-main","container-compact"]).with("comfortable",()=>["container-main","container-comfortable"]).with("default",()=>["container-main","container-default"]).otherwise(()=>["container-main","container-default"]),e=[];return a.class&&(typeof a.class=="string"?e.push(a.class):Array.isArray(a.class)?e.push(...a.class):Object.entries(a.class).forEach(([t,c])=>{c&&e.push(t)})),[...n,...e].join(" ")});return{containerProps:r,containerClasses:o}},B={variant:"default",fluid:!0},D=m({__name:"Container",props:d({variant:{},fluid:{type:Boolean},tag:{},class:{},style:{}},B),setup(a){const s=a,r=w(),o=i(()=>r.current.value.dark),{containerProps:n,containerClasses:e}=k(s,o.value);return(t,c)=>(v(),p(y,_(u(n),{class:u(e)}),h({_:2},[C(t.$slots,(j,l)=>({name:l,fn:P(()=>[b(t.$slots,l,{},void 0,!0)])}))]),1040,["class"]))}}),$=g(D,[["__scopeId","data-v-b8d6ce90"]]);export{$ as C};
