.header.v-toolbar[data-v-42cfb676]{height:55px;font-family:JetBrains Mono Medium}.header.v-toolbar[data-v-42cfb676] .v-toolbar__content{height:55px!important;min-height:55px!important;padding-top:0;padding-bottom:0;align-items:center}.header.v-toolbar[data-v-42cfb676] .v-toolbar-title{margin-inline-start:10px!important}.header.v-toolbar[data-v-42cfb676] .v-toolbar__prepend{margin-inline-start:12px!important;margin-inline-end:0px!important}.header.v-toolbar>.v-toolbar__content>.v-toolbar__append[data-v-42cfb676]{margin-inline-end:5px}.header.v-toolbar-default>.v-toolbar__content>.v-toolbar__append[data-v-42cfb676]{margin-inline-end:10px}.toolbar-prepend[data-v-42cfb676]{display:flex;align-items:center;gap:.5rem}
